call abstract method
Translates a TerminalKeyboardEvent into an escape sequence. If the event cannot be translated, null is returned.
Implementation
String? call(TerminalKeyboardEvent event);
Translates a TerminalKeyboardEvent into an escape sequence. If the event cannot be translated, null is returned.
String? call(TerminalKeyboardEvent event);