TerminalStyle class
Constructors
-
TerminalStyle({double fontSize = _kDefaultFontSize, double height = _kDefaultHeight, String fontFamily = _kDefaultFontFamily, List<
String> fontFamilyFallback = _kDefaultFontFamilyFallback, List<FontFeature> fontFeatures = _kDefaultFontFeatures}) -
const
- TerminalStyle.fromTextStyle(TextStyle textStyle)
-
factory
Properties
- fontFamily → String
-
final
-
fontFamilyFallback
→ List<
String> -
final
-
fontFeatures
→ List<
FontFeature> -
final
- fontSize → double
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- height → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{double? fontSize, double? height, String? fontFamily, List< String> ? fontFamilyFallback, List<FontFeature> ? fontFeatures}) → TerminalStyle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toStrutStyle(
) → StrutStyle - Forces every line to the primary font's metrics.
-
toTextStyle(
{Color? color, Color? backgroundColor, bool bold = false, bool italic = false}) → TextStyle - Underlines are never rendered: CellFlags.underline is ignored and the style always resolves to TextDecoration.none.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override